from __future__ import print_function

import os
import sys
from optparse import OptionParser

from .googledrive import GoogleDrive

__version__ = "0.2"

parser = OptionParser()
parser.add_option("-q", "--quiet",
                  action="store_false", dest="verbose", default=True,
                  help="don't print status messages to stdout")
parser.add_option("-m", "--mime",
                  action="store", dest="mimeoption", default=False,
                  help="Mime type search input Ex: image/jpeg for jpg/jpeg files")
parser.add_option("-n", "--name-search",
                  action="store", dest="filename", default=False,
                  help="Search only on file names")
parser.add_option("-f", "--full-text-search",
                  action="store", dest="fulltext", default=False,
                  help="Search in file and file names")
parser.add_option("-d", "--disk",
                  action="store", dest="disk", default=False,
                  help="Select a disk. Avaiable options: 'google-drive, mega'")

(options, args) = parser.parse_args()
DEFAULT_PAGE_SIZE_GOOGLE = 100


def checkGoogleAPI():
    if os.path.exists("client_secret.json"):
        return 1
    else:
        return 0


def main():
    gDrive = False
    mega = False
    if options.disk == "google-drive":
        # Show Google Drive Panel
        if not checkGoogleAPI():
            print("Google client_secret.json not found. Please check your configuration.")
            main()
        else:
            Drive = GoogleDrive()
            items = Drive.getWebContentLink(options.fulltext)
            for item in items:
                print('{0}&name={1}'.format(item['webContentLink'],item['name']))

    elif options.disk == "mega":
        # Show Mega Panel
        nothing = 1
    else:
        sys.exit(0)






import os
import io
import httplib2
import mimetypes

from apiclient import discovery
from googleapiclient.http import MediaIoBaseDownload, MediaFileUpload
from oauth2client import client
from oauth2client import tools
from oauth2client.file import Storage

SCOPES = 'https://www.googleapis.com/auth/drive.metadata.readonly'
CLIENT_SECRET_FILE = 'client_secret.json'


class GoogleDrive:

    def __init__(self):
        self.credentials = self.getCredientials()
        self.http = self.credentials.authorize(httplib2.Http())
        self.service = discovery.build('drive', 'v3', http=self.http)


    def getCredientials(self):
        home_dir = os.path.expanduser('~')
        credential_dir = os.path.join(home_dir, '.credentials')
        if not os.path.exists(credential_dir):
            os.makedirs(credential_dir)
        credential_path = os.path.join(credential_dir,
                                       'aiodisk.json')

        store = Storage(credential_path)
        credentials = store.get()
        if not credentials or credentials.invalid:
            flow = client.flow_from_clientsecrets(CLIENT_SECRET_FILE, SCOPES)
            credentials = tools.run_flow(flow, store)

            print('Storing credentials to ' + credential_path)
        return credentials

    def getLastItems(self, size):
        results = self.service.files().list(
            pageSize=size, spaces='drive', fields="nextPageToken, files(id, name)").execute()
        items = results.get('files', [])
        return items

    def searchWithMimeType(self, mimestring):
        results = self.service.files().list(q="mimeType='" + mimestring + "'",
                                              spaces='drive',
                                              fields='nextPageToken, files(id, name)',
                                              pageToken=None).execute()
        items = results.get('files', [])
        return items

    def searchWithName(self, namestring):
        results = self.service.files().list(q="name contains '" + namestring + "'",
                                            spaces='drive',
                                            fields='nextPageToken, files(id, name)',
                                            pageToken=None).execute()
        items = results.get('files', [])
        return items

    def searchWithFullText(self, fulltextstring):
        results = self.service.files().list(q="fullText contains '" + fulltextstring + "'",
                                            spaces='drive',
                                            fields='nextPageToken, files(id, name)',
                                            pageToken=None).execute()
        items = results.get('files', [])
        return items

    def getWebContentLink(self, namestring):
        results = self.service.files().list(q="fullText contains '" + namestring + "'",
                                            spaces='drive',
                                            fields='nextPageToken, files(webContentLink,name)',
                                            pageToken=None).execute()
        items = results.get('files', [])
        return items

    def uploadFile(self, filename):
        file_metadata = {'name': filename}
        media = MediaFileUpload('files/photo.jpg',
                                mimetype='image/jpeg')
        file = self.service.files().create(body=file_metadata,
                                            media_body=media,
                                            fields='id').execute()
        print('File ID: %s' % file.get('id'))











import re
from setuptools import setup

version = re.search(
    '^__version__\s*=\s*"(.*)"',
    open('aiodisk/aiodisk.py').read(),
    re.M
    ).group(1)

setup(
    name='aiodisk',
    packages=['aiodisk'],  # this must be the same as the name above
    version=version,
    description='Access all cloud services in one script',
    author='Oguz BAKIR',
    author_email='worms298@gmail.com',
    url='https://github.com/oguzbakir/AioDisk',  # use the URL to the github repo
    download_url='https://github.com/oguzbakir/aiodisk/archive/0.1.tar.gz',
    keywords=['drive', 'mega', 'cloud', 'cloudaio'],  # arbitrary keywords
    classifiers=['Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.6'],
    entry_points = {
        "console_scripts": ['aiodisk = aiodisk.aiodisk:main']
        },
    install_requires=[
        'google-api-python-client',
    ],
)
